#include <stdlib.h>
#include <stdio.h>
void jsoo_get_bytecode_sections () {
  fprintf(stderr, "Unimplemented Javascript primitive jsoo_get_bytecode_sections!\n");
  exit(1);
}

void jsoo_get_runtime_aliases () {
  fprintf(stderr, "Unimplemented Javascript primitive jsoo_get_runtime_aliases!\n");
  exit(1);
}

void jsoo_toplevel_init_compile () {
  fprintf(stderr, "Unimplemented Javascript primitive jsoo_toplevel_init_compile!\n");
  exit(1);
}

void jsoo_toplevel_init_reloc () {
  fprintf(stderr, "Unimplemented Javascript primitive jsoo_toplevel_init_reloc!\n");
  exit(1);
}
